@@ -40,16 +40,15 @@ test_that("test diagnosands", {
 
 
 test_that("Bootstrap ses close", {
-  skip("Skipped bootstrap SE test for speed")
-  
+  # skip("Skipped bootstrap SE test for speed")
   pop <- declare_model(N = 100, S100 = rnorm(N, sd = 100), S10000 = rnorm(N, sd = 10000))
   inquiry <- declare_inquiry(S100 = mean(S100), S10000 = mean(S10000))
   estimate <- declare_estimator(S100 ~ S10000, .method = lm, inquiry = list("S100", "S10000"))
   design <- pop + inquiry + estimate
-  d <- diagnose_design(design, sims = 10000)
+  d <- diagnose_design(design, sims = 1000)
   expect_true(d$diagnosands_df$`se(mean_estimand)`[1] > .06)
-  expect_true(d$diagnosands_df$`se(mean_estimand)`[1] < .14)
+  expect_true(d$diagnosands_df$`se(mean_estimand)`[1] < .4)
   expect_true(d$diagnosands_df$`se(mean_estimand)`[2] > 6)
-  expect_true(d$diagnosands_df$`se(mean_estimand)`[2] < 14)
+  expect_true(d$diagnosands_df$`se(mean_estimand)`[2] < 40)
 })
 
