@@ -87,5 +87,5 @@ test_that("compare_diagnoses errors when it should", {
 
 
 test_that("compare_diagnoses prints", {
-  expect_output(DeclareDesign:::print.compared_diagnoses(comparison))
+  expect_output(print.compared_diagnoses(comparison))
 })
