@@ -1,7 +1,7 @@
 context("declare step")
 
 test_that("test declare step ", {
-  my_population <- declare_population(N = 50, noise = rnorm(N))
+  my_population <- declare_model(N = 50, noise = rnorm(N))
   my_assignment <- declare_assignment(Z = complete_ra(N, m = 25))
   my_step <- declare_step(fabricate, Z2 = Z, q = 5)
 
