@@ -17,18 +17,18 @@ expect_estimates <- function(estimates, label = NULL) {
 
 test_that("difference in means", {
   my_estimator <- declare_estimator(Y ~ Z)
-  my_population() %>% my_potential_outcomes() %>% my_assignment() %>% my_measurement() %>% my_estimator() %>% expect_estimates()
+  my_population() |> my_potential_outcomes() |> my_assignment() |> my_measurement() |> my_estimator() |> expect_estimates()
 })
 
 test_that("lm with robust ses", {
   my_estimator <- declare_estimator(Y ~ Z, .method = lm_robust)
-  my_population() %>% my_potential_outcomes() %>% my_assignment() %>% my_measurement() %>% my_estimator() %>% expect_estimates()
+  my_population() |> my_potential_outcomes() |> my_assignment() |> my_measurement() |> my_estimator() |> expect_estimates()
 })
 
 
 test_that("lm with HC3 robust ses", {
   my_estimator <- declare_estimator(Y ~ Z, .method = lm_robust, se_type = "HC3")
-  my_population() %>% my_potential_outcomes() %>% my_assignment() %>% my_measurement() %>% my_estimator() %>% expect_estimates()
+  my_population() |> my_potential_outcomes() |> my_assignment() |> my_measurement() |> my_estimator() |> expect_estimates()
 })
 
 test_that("custom estimator function", {
@@ -36,7 +36,7 @@ test_that("custom estimator function", {
     data.frame(estimate = with(data, 2), foo = mean(data$Y))
   }
   my_estimator_custom <- declare_estimator(handler = label_estimator(my_mean))
-  cust <- my_population() %>% my_potential_outcomes() %>% my_assignment() %>% my_measurement() %>% my_estimator_custom()
+  cust <- my_population() |> my_potential_outcomes() |> my_assignment() |> my_measurement() |> my_estimator_custom()
   expect_equal(cust$estimate, 2)
 })
 
@@ -47,11 +47,11 @@ test_that("check blocked d-i-m estimator", {
 
   ## lm with HC3 robust ses
   my_estimator_blocked <- declare_estimator(Y ~ Z, .method = difference_in_means, blocks = `blocks`)
-  df <- my_population() %>% my_potential_outcomes() %>% my_assignment() %>% my_measurement()
+  df <- my_population() |> my_potential_outcomes() |> my_assignment() |> my_measurement()
   my_estimator_notblocked <- declare_estimator(Y ~ Z)
 
-  df %>% my_estimator_notblocked() %>% expect_estimates()
-  df %>% my_estimator_blocked() %>% expect_estimates() ## it is different!
+  df |> my_estimator_notblocked() |> expect_estimates()
+  df |> my_estimator_blocked() |> expect_estimates() ## it is different!
 })
 
 
@@ -202,39 +202,39 @@ df <- data.frame(
 
 test_that("labels for estimates and inquiries work inquiry splat labeld estimator default", {
   mator_no_label <- declare_estimator(Y ~ Z, inquiry = inquiry_arg_label)
-  df %>% mator_no_label() %>% expect_label("estimator", "ATE")
+  df |> mator_no_label() |> expect_label("estimator", "ATE")
 })
 
 test_that("labels for estimates and inquiries work, label explicit, inquiry splat labeled", {
   mator_label <- declare_estimator(Y ~ Z, inquiry = inquiry_arg_label, label = "an_estimator")
-  df %>% mator_label() %>% expect_label("an_estimator", "ATE")
+  df |> mator_label() |> expect_label("an_estimator", "ATE")
 })
 
 test_that("labels for estimates and inquiries work inquiry splat labeld label =NULL", {
   mator_label_null <- declare_estimator(Y ~ Z, inquiry = inquiry_arg_label, label = NULL)
-  expect_error(df %>% mator_label_null())
+  expect_error(df |> mator_label_null())
 })
 
 test_that("labels for estimates and inquiries work - label default", {
   mator_no_label <- declare_estimator(Y ~ Z, inquiry = inquiry_explicit_label)
-  df %>% mator_no_label() %>% expect_label("estimator", "ATE")
+  df |> mator_no_label() |> expect_label("estimator", "ATE")
 })
 
 test_that("labels for estimates and inquiries work - label explicit", {
   mator_label <- declare_estimator(Y ~ Z, inquiry = inquiry_explicit_label, label = "an_estimator")
   # mator_label_noquote <- declare_estimator(Y ~ Z, inquiry = inquiry_explicit_label, label = an_estimator)
-  df %>% mator_label() %>% expect_label("an_estimator", "ATE")
+  df |> mator_label() |> expect_label("an_estimator", "ATE")
 })
 
 test_that("labels for estimates and inquiries work- label=NULL", {
   mator_label_null <- declare_estimator(Y ~ Z, inquiry = inquiry_explicit_label, label = NULL)
-  expect_error(df %>% mator_label_null())
+  expect_error(df |> mator_label_null())
 })
 
 
 test_that("labels for estimates and inquiries work inquiry label, estimator default", {
   mator_no_label <- declare_estimator(Y ~ Z, inquiry = inquiry_explicit_label)
-  df %>% mator_no_label() %>% expect_label("estimator", "ATE")
+  df |> mator_no_label() |> expect_label("estimator", "ATE")
 })
 
 
