@@ -2,7 +2,7 @@ context("print")
 
 N <- 500
 
-my_population <- declare_population(N = N, noise = rnorm(N))
+my_population <- declare_model(N = N, noise = rnorm(N))
 
 my_potential_outcomes <- declare_potential_outcomes(Y_Z_0 = noise, Y_Z_1 = noise + rnorm(N, mean = 2, sd = 2))
 
@@ -14,7 +14,7 @@ my_inquiry <- declare_inquiry(ATE = mean(Y_Z_1 - Y_Z_0))
 
 my_estimator <- declare_estimator(Y ~ Z, inquiry = my_inquiry)
 
-my_reveal <- declare_reveal()
+my_measurement <- declare_measurement(Y = reveal_outcomes(Y ~ Z)) 
 
 design <- my_population +
   my_potential_outcomes +
@@ -23,7 +23,7 @@ design <- my_population +
   declare_step(dplyr::mutate, q = 5) +
   declare_step(dplyr::mutate, q = 6) +
   my_assignment +
-  my_reveal +
+  my_measurement +
   my_estimator
 
 test_that("print code works", {
@@ -38,10 +38,10 @@ test_that("print code works", {
 # test_that("print full design", {
 #
 #   expect_equal(capture.output(print_code(design)),
-#                c("my_population <- declare_population(N = N, noise = rnorm(N)) ",
+#                c("my_population <- declare_model(N = N, noise = rnorm(N)) ",
 #                  "", "my_potential_outcomes <- declare_potential_outcomes(Y_Z_0 = noise, Y_Z_1 = noise + rnorm(N, mean = 2, sd = 2)) ",
 #                  "", "my_sampling <- declare_sampling(S = complete_rs(N, n = 250)) ", "", "my_inquiry <- declare_inquiry(ATE = mean(Y_Z_1 - Y_Z_0)) ",
-#                  "", "my_assignment <- declare_assignment(Z = complete_ra(N, m = 25)) ", "", "my_reveal <- declare_reveal() ",
+#                  "", "my_assignment <- declare_assignment(Z = complete_ra(N, m = 25)) ", "", "my_measurement <- declare_measurement(Y = reveal_outcomes(Y ~ Z)",
 #                  "", "my_estimator <- declare_estimator(Y ~ Z, inquiry = my_inquiry) ",
 #                  "", "my_design <- my_population + my_potential_outcomes + my_sampling + my_inquiry + dplyr::mutate(q = 5) + dplyr::mutate(q = 6) + my_assignment + my_reveal + my_estimator) ",
 #                  ""))
@@ -49,5 +49,5 @@ test_that("print code works", {
 # })
 
 test_that("print a step", {
-  expect_equal(capture.output(print(my_reveal)), "declare_reveal()")
+  expect_equal(capture.output(print(my_measurement)), "declare_measurement(Y = reveal_outcomes(Y ~ Z))")
 })
