@@ -112,3 +112,36 @@ test_that("designs with some estimators that don't have p.values return the p.va
   
 })
 
+
+
+
+# fan out
+test_that("Check new sim ids", {
+  skip_if_not_installed("DesignLibrary")
+  testthat::skip("test requires updated DesignLbrary")    
+  skip_on_cran()
+  design <- DesignLibrary::two_arm_designer()
+  
+  Sys.setenv(TESTTHAT='m')
+  sx <- expect_warning(simulate_design(design, sims = c(2,  1, 1, 2)))
+  Sys.setenv(TESTTHAT='true')
+  
+  expect_equal(sx$step_1_draw, c(1L, 1L, 2L, 2L))
+  expect_equal(sx$step_4_draw, c(1L, 2L, 3L, 4L))
+  expect_equal(sx$estimate[1], sx$estimate[2])
+  expect_equal(sx$estimate[3], sx$estimate[4])
+})
+
+
+test_that("fan out IDs are correct", {
+  testthat::skip("test requires updated DesignLbrary")    
+  skip_if_not_installed("DesignLibrary")
+  skip_on_cran()
+  
+  sims <- c(30, 1, 2, 2)
+  design <- DesignLibrary::two_arm_designer(rho = 0)
+  
+  sx <- simulate_design(design, sims = sims)
+  
+  expect_equivalent(vapply(sx[c("step_1_draw", "step_3_draw", "step_4_draw")], max, 0), c(30, 60, 120))
+})
\ No newline at end of file
